Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(857)

Unified Diff: cc/tiles/image_decode_cache.h

Issue 2541183002: cc: Rename ImageDecodeController to ImageDecodeCache. (Closed)
Patch Set: rename: update Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/tiles/gpu_image_decode_controller_unittest.cc ('k') | cc/tiles/image_decode_controller.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/tiles/image_decode_cache.h
diff --git a/cc/tiles/image_decode_controller.h b/cc/tiles/image_decode_cache.h
similarity index 87%
rename from cc/tiles/image_decode_controller.h
rename to cc/tiles/image_decode_cache.h
index 10e93988ef9cd14fe351280bcfd2e60b5fd2550d..d20ed37fad3a8eabada8cfc41242aeb89ecccaac 100644
--- a/cc/tiles/image_decode_controller.h
+++ b/cc/tiles/image_decode_cache.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CC_TILES_IMAGE_DECODE_CONTROLLER_H_
-#define CC_TILES_IMAGE_DECODE_CONTROLLER_H_
+#ifndef CC_TILES_IMAGE_DECODE_CACHE_H_
+#define CC_TILES_IMAGE_DECODE_CACHE_H_
#include "base/memory/ref_counted.h"
#include "cc/playback/decoded_draw_image.h"
@@ -14,11 +14,11 @@ namespace cc {
class TileTask;
// ImageDecodeController is responsible for generating decode tasks, decoding
// images, storing images in cache, and being able to return the decoded images
// when requested.
// ImageDecodeController is responsible for the following things:
// 1. Given a DrawImage, it can return an TileTask which when run will
// decode and cache the resulting image. If the image does not need a task to
// be decoded, then nullptr will be returned. The return value of the
@@ -32,7 +32,7 @@ class TileTask;
// and it needs to be scaled/decoded, then this decode will happen as part of
// getting the image. As such, this should only be accessed from a raster
// thread.
-class CC_EXPORT ImageDecodeController {
+class CC_EXPORT ImageDecodeCache {
public:
// This information should be used strictly in tracing, UMA, and any other
// reporting systems.
@@ -50,7 +50,7 @@ class CC_EXPORT ImageDecodeController {
const TilePriority::PriorityBin requesting_tile_bin;
};
- virtual ~ImageDecodeController() {}
+ virtual ~ImageDecodeCache() {}
// Fill in an TileTask which will decode the given image when run. In
// case the image is already cached, fills in nullptr. Returns true if the
@@ -76,11 +76,11 @@ class CC_EXPORT ImageDecodeController {
virtual void DrawWithImageFinished(const DrawImage& image,
const DecodedDrawImage& decoded_image) = 0;
// This function informs the controller that now is a good time to clean up
// memory. This is called periodically from the compositor thread.
virtual void ReduceCacheUsage() = 0;
// This function informs the controller that we are hidden and should not be
// retaining cached resources longer than needed.
virtual void SetShouldAggressivelyFreeResources(
bool aggressively_free_resources) = 0;
@@ -88,4 +88,4 @@ class CC_EXPORT ImageDecodeController {
} // namespace cc
-#endif // CC_TILES_IMAGE_DECODE_CONTROLLER_H_
+#endif // CC_TILES_IMAGE_DECODE_CACHE_H_
« no previous file with comments | « cc/tiles/gpu_image_decode_controller_unittest.cc ('k') | cc/tiles/image_decode_controller.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -14,11 +14,11 @@ namespace cc {
class TileTask;
-// ImageDecodeController is responsible for generating decode tasks, decoding
+// ImageDecodeCache is responsible for generating decode tasks, decoding
// images, storing images in cache, and being able to return the decoded images
// when requested.
@@ -14,11 +14,11 @@ namespace cc {
// images, storing images in cache, and being able to return the decoded images
// when requested.
-// ImageDecodeController is responsible for the following things:
+// ImageDecodeCache is responsible for the following things:
// 1. Given a DrawImage, it can return an TileTask which when run will
// decode and cache the resulting image. If the image does not need a task to
@@ -76,11 +76,11 @@ class CC_EXPORT ImageDecodeController {
virtual void DrawWithImageFinished(const DrawImage& image,
const DecodedDrawImage& decoded_image) = 0;
- // This function informs the controller that now is a good time to clean up
+ // This function informs the cache that now is a good time to clean up
// memory. This is called periodically from the compositor thread.
virtual void ReduceCacheUsage() = 0;
@@ -76,11 +76,11 @@ class CC_EXPORT ImageDecodeController {
// memory. This is called periodically from the compositor thread.
virtual void ReduceCacheUsage() = 0;
- // This function informs the controller that we are hidden and should not be
+ // This function informs the cache that we are hidden and should not be
// retaining cached resources longer than needed.
virtual void SetShouldAggressivelyFreeResources(
This is Rietveld 408576698